<?php
/**
 * Plugin Name: IHWEBANALYTICS
 * Plugin URI: https://infhor.de/ihwebanalytics-portal/
 * Description: Fügt einen anpassbaren Tracking-Code hinzu und bietet eine Infoseite mit Links zu IH Web Analytics.
 * Version: 1.1
 * Author: Infinite Horizons UG(haftungsbeschränkt)
 * Author URI: https://infhor.de/
 */

// Verhindere direkten Zugriff
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

// Tracking-Code in den Header einfügen
function ihwebanalytics_add_tracking_code() {
    $tracking_code = get_option( 'ihwebanalytics_tracking_code', '' );
    if ( ! empty( $tracking_code ) ) {
        echo $tracking_code; // Gib den Tracking-Code direkt aus
    }
}
add_action( 'wp_head', 'ihwebanalytics_add_tracking_code' );

// Admin-Menü hinzufügen
function ihwebanalytics_admin_menu() {
    add_menu_page(
        'IHWEBANALYTICS', // Seitenname
        'Analytics', // Menüname
        'manage_options',   // Berechtigungen
        'ihwebanalytics',   // Slug
        'ihwebanalytics_settings_page', // Callback-Funktion
        'dashicons-chart-area', // Icon
        20 // Position
    );
}
add_action( 'admin_menu', 'ihwebanalytics_admin_menu' );

// Inhalt der Plugin-Einstellungsseite
function ihwebanalytics_settings_page() {
    // Speichere die Optionen bei einem POST-Request
    if ( isset( $_POST['ihwebanalytics_save_settings'] ) ) {
        check_admin_referer( 'ihwebanalytics_save_settings' );
        $tracking_code = wp_unslash($_POST['ihwebanalytics_tracking_code']); // Entferne Slashes
        update_option( 'ihwebanalytics_tracking_code', $tracking_code );
        echo '<div class="updated"><p>Einstellungen gespeichert.</p></div>';
    }

    $saved_tracking_code = get_option( 'ihwebanalytics_tracking_code', '' );
    ?>
    <div class="wrap">
        <h1>Einstellungen für IHWEBANALYTICS</h1>
        <p>Bitte überprüfen Sie die Einstellungen des Cookie-Banners, um sicherzustellen, dass das Tracking-Tool tatsächlich blockiert wird, solange keine Einwilligung des Nutzers vorliegt. Nur so kann die Einbindung des Tools datenschutzkonform erfolgen.</p>
        <form method="post">
            <?php wp_nonce_field( 'ihwebanalytics_save_settings' ); ?>
            <table class="form-table">
                <tr>
                    <th scope="row">
                        <label for="ihwebanalytics_tracking_code">Tracking-Code</label>
                    </th>
                    <td>
                        <textarea name="ihwebanalytics_tracking_code" id="ihwebanalytics_tracking_code" rows="10" cols="50" class="large-text"><?php echo esc_textarea( $saved_tracking_code ); ?></textarea>
                        <p class="description">Fügen Sie hier Ihren Tracking-Code ein.</p>
                    </td>
                </tr>
            </table>
            <p>
                <a href="https://infhor.de/ihwebanalytics-portal/" class="button button-primary" target="_blank">Zum Software-Portal</a>
                <a href="https://ihwebanalytics.infhor.de/" class="button" target="_blank">Zum Login</a>
            </p>
            <p>
                <input type="submit" name="ihwebanalytics_save_settings" class="button button-primary" value="Einstellungen speichern">
            </p>
        </form>
    </div>
    <?php
}
